__version__ = '0.3.12'

__authors__ = [
    ("Thomas G. Close", "tom.g.close@gmail.com"),
    ("Francesco Sforazzini", "francesco.sforazzini@gmail.com"),
    ("Phillip G. D. Ward", "phillipgdward@gmail.com")]


install_requires = ['arcana>=0.4.12',
                    'pydicom>=1.0',
                    'nibabel>=2.3.0',
                    'pybids>=0.9.1']
